@@ -9,14 +9,11 @@ import (
 	"path/filepath"
 )
 
-// Cache returns the base cache directory.
-func Cache() string {
-	return cache()
-}
+// TODO: replace with https://github.com/golang/go/issues/29960 if accepted.
 
 // Data returns the base data directory.
 func Data() string {
-	return data()
+	return dataDir
 }
 
 func firstGetenv(def string, evs ...string) string {
@@ -25,17 +22,14 @@ func firstGetenv(def string, evs ...string) string {
 			return v
 		}
 	}
-	home, err := homeDir()
-	if err != nil {
-		return ""
+	// TODO: replace with os.UserHomeDir once we require Go 1.12 or later.
+	home := os.Getenv("HOME")
+	if home == "" {
+		curUser, err := user.Current()
+		if err != nil {
+			return ""
+		}
+		home = curUser.HomeDir
 	}
 	return filepath.Join(home, def)
 }
-
-func homeDir() (string, error) {
-	curUser, err := user.Current()
-	if err != nil {
-		return "", err
-	}
-	return curUser.HomeDir, nil
-}
